#~ ***********************************************************************************
#~ ***********************************************************************************
#~ FOSS4G 2016 Tutoriel :  Traitement de données aéroportées avec MicMac [W7]
						#~ Ewelina Rupnik - Mehdi Daakir
						#~ Contact : ewelina.rupnik@ensg.eu / mehdi.daakir@ensg.eu 
#~ ***********************************************************************************
#~ ***********************************************************************************


#~ *********************** Pipeline MicMac Commands : *********************** ~#


echo "-------------------------------------------------------------------------------------------------------------------------------------"
echo "Tie points extraction : "
echo "mm3d Tapioca MulScale \"Abbey-IMG_.*.jpg\" 200 800"
mm3d Tapioca MulScale "Abbey-IMG_.*.jpg" 200 800 > output.txt
echo "-------------------------------------------------------------------------------------------------------------------------------------"

echo "-------------------------------------------------------------------------------------------------------------------------------------"
echo "Tie points visualization between 2 images"
echo "mm3d SEL ./ Abbey-IMG_0211.jpg Abbey-IMG_0212.jpg KH=NB R=1"
mm3d SEL ./ Abbey-IMG_0211.jpg Abbey-IMG_0212.jpg KH=NB R=1 >> output.txt
echo "-------------------------------------------------------------------------------------------------------------------------------------"

echo "-------------------------------------------------------------------------------------------------------------------------------------"
echo "Compute a sub-bloc of images to initialize internal parameters"
echo "mm3d Tapas RadialBasic \"Abbey-IMG_(0248|0247|0249|0238|0239|0240).jpg\" Out=Calib "
time -p mm3d Tapas RadialBasic "Abbey-IMG_(0248|0247|0249|0238|0239|0240).jpg" Out=Calib >> output.txt
echo "-------------------------------------------------------------------------------------------------------------------------------------"

echo "-------------------------------------------------------------------------------------------------------------------------------------"
echo "Compute fast positions/orientations of all images (useful for large datasets)"
echo "mm3d Martini \"Abbey-IMG_.*.jpg\" OriCalib=Calib "
time -p mm3d Martini "Abbey-IMG_.*.jpg" OriCalib=Calib >> output.txt
echo "-------------------------------------------------------------------------------------------------------------------------------------"

echo "-------------------------------------------------------------------------------------------------------------------------------------"
echo "Compute positions/orientations of all images based in previous"
echo "mm3d Tapas AutoCal \"Abbey-.*.jpg\" InOri=MartiniCalib Out=All "
time -p mm3d Tapas AutoCal "Abbey-.*.jpg" InOri=MartiniCalib Out=All >> output.txt
echo "-------------------------------------------------------------------------------------------------------------------------------------"

echo "-------------------------------------------------------------------------------------------------------------------------------------"
echo "Generate a .ply file to visualize positions/orientations of all images and tie points"
echo "mm3d AperiCloud  \"Abbey-IMG_[0-9]*.jpg\" All "
time -p mm3d AperiCloud  "Abbey-IMG_[0-9]*.jpg" All >> output.txt
echo "-------------------------------------------------------------------------------------------------------------------------------------"

echo "-------------------------------------------------------------------------------------------------------------------------------------"
echo "Visualize the previous ply file"
echo "meshlab AperiCloud_All.ply"
meshlab AperiCloud_All.ply
echo "-------------------------------------------------------------------------------------------------------------------------------------"

echo "-------------------------------------------------------------------------------------------------------------------------------------"
echo "Convertion of .txt file of ground points measurements into .xml format"
echo "mm3d GCPConvert \"#F=N_X_Y_Z\" 120601.txt ChSys=DegreeWGS84@SysCoRTL.xml Out=AppRTL.xml "
time -p mm3d GCPConvert "#F=N_X_Y_Z" 120601.txt ChSys=DegreeWGS84@SysCoRTL.xml Out=AppRTL.xml >> output.txt
echo "-------------------------------------------------------------------------------------------------------------------------------------"

echo "-------------------------------------------------------------------------------------------------------------------------------------"
echo "Measure the ground points in the images (only 3 points to start)"
echo "mm3d SaisieAppuisInitQT  \"Abbey-IMG_0211.jpg|Abbey-IMG_0234.jpg\"  All  NamePointInit.txt  MesureInit.xml "
mm3d SaisieAppuisInitQT  "Abbey-IMG_0211.jpg|Abbey-IMG_0234.jpg"  All  NamePointInit.txt  MesureInit.xml >> output.txt
echo "-------------------------------------------------------------------------------------------------------------------------------------"

echo "-------------------------------------------------------------------------------------------------------------------------------------"
echo "Make a first system conversion into absolute one based only on the 3 previous points"
echo "mm3d GCPBascule \"Abbey-.*jpg\" All RTL-Init AppRTL.xml MesureInit-S2D.xml "
time -p mm3d GCPBascule "Abbey-.*jpg" All RTL-Init AppRTL.xml MesureInit-S2D.xml >> output.txt
echo "-------------------------------------------------------------------------------------------------------------------------------------"


echo "-------------------------------------------------------------------------------------------------------------------------------------"
echo "Project all available ground points on images based on previsous system conversion and make image measurements"
echo "mm3d SaisieAppuisPredicQT  \"Abbey-.*jpg\" RTL-Init AppRTL.xml  MesureFinale.xml "
mm3d SaisieAppuisPredicQT  "Abbey-.*jpg" RTL-Init AppRTL.xml  MesureFinale.xml >> output.txt
echo "-------------------------------------------------------------------------------------------------------------------------------------"


echo "-------------------------------------------------------------------------------------------------------------------------------------"
echo "Make a final system conversion based on all ground points "
echo "mm3d GCPBascule \"Abbey.*jpg\" All  RTL-Bascule AppRTL.xml MesureFinale-S2D.xml "
time -p mm3d GCPBascule "Abbey.*jpg" All  RTL-Bascule AppRTL.xml MesureFinale-S2D.xml >> output.txt
echo "-------------------------------------------------------------------------------------------------------------------------------------"

echo "-------------------------------------------------------------------------------------------------------------------------------------"
echo "Make compensation based on tie points and ground measurements and refine internal parameters"
echo "mm3d Campari \"Abbey.*.jpg\"  RTL-Bascule RTL-Compense GCP=[AppRTL.xml,0.1,MesureFinale-S2D.xml,0.5] AllFree=true "
time -p mm3d Campari "Abbey.*.jpg"  RTL-Bascule RTL-Compense GCP=[AppRTL.xml,0.1,MesureFinale-S2D.xml,0.5] AllFree=true >> output.txt
echo "-------------------------------------------------------------------------------------------------------------------------------------"

echo "-------------------------------------------------------------------------------------------------------------------------------------"
echo "Change system coordinates to express the results in a cartographic projection"
echo "mm3d ChgSysCo  \"Abbey.*.jpg\" RTL-Compense SysCoRTL.xml@Lambert93 L93 "
time -p mm3d ChgSysCo  "Abbey.*.jpg" RTL-Compense SysCoRTL.xml@Lambert93 L93 >> output.txt
echo "-------------------------------------------------------------------------------------------------------------------------------------"

echo "-------------------------------------------------------------------------------------------------------------------------------------"
echo "Make a first mosaic of the scene"
echo "mm3d Tarama  \"Abbey.*.jpg\" L93 "
time -p mm3d Tarama  "Abbey.*.jpg" L93 >> output.txt
echo "-------------------------------------------------------------------------------------------------------------------------------------"

echo "-------------------------------------------------------------------------------------------------------------------------------------"
echo "Draw a mask on the mosaic of the scene to keep only interest area"
echo "mm3d SaisieMasqQT TA/TA_LeChantier.tif"
mm3d SaisieMasqQT TA/TA_LeChantier.tif
echo "-------------------------------------------------------------------------------------------------------------------------------------"

echo "-------------------------------------------------------------------------------------------------------------------------------------"
echo "Make image maching to produce all photogrammetric products"
echo "mm3d Malt Ortho  \"Abbey.*.jpg\" L93 SzW=1 DefCor=0.0 ZoomF=2 NbVI=2 ResolOrtho=0.5 "
time -p mm3d Malt Ortho  "Abbey.*.jpg" L93 SzW=1 DefCor=0.0 ZoomF=2 NbVI=2 ResolOrtho=0.5 >> output.txt
echo "-------------------------------------------------------------------------------------------------------------------------------------"

echo "-------------------------------------------------------------------------------------------------------------------------------------"
echo "Make othoimage mosaic based on individuel one"
echo "mm3d Tawny Ortho-MEC-Malt/ "
time -p mm3d Tawny Ortho-MEC-Malt/ >> output.txt
echo "-------------------------------------------------------------------------------------------------------------------------------------"

echo "-------------------------------------------------------------------------------------------------------------------------------------"
echo "Make a shading representation of depth map"
echo "mm3d GrShade MEC-Malt/Z_Num8_DeZoom2_STD-MALT.tif Out=shading.tif ModeOmbre=IgnE "
time -p mm3d GrShade MEC-Malt/Z_Num8_DeZoom2_STD-MALT.tif Out=shading.tif ModeOmbre=IgnE >> output.txt
echo "-------------------------------------------------------------------------------------------------------------------------------------"

echo "-------------------------------------------------------------------------------------------------------------------------------------"
echo "Make a hypsometric representation of depth map"
echo "mm3d to8bits MEC-Malt/Z_Num8_DeZoom2_STD-MALT.tif Out=hypso.tif Circ=1 "
time -p mm3d to8bits MEC-Malt/Z_Num8_DeZoom2_STD-MALT.tif Out=hypso.tif Circ=1 >> output.txt
echo "-------------------------------------------------------------------------------------------------------------------------------------"

echo "-------------------------------------------------------------------------------------------------------------------------------------"
echo "Export 3d point cloud"
echo "mm3d Nuage2Ply MEC-Malt/NuageImProf_STD-MALT_Etape_8.xml Attr=Ortho-MEC-Malt/Orthophotomosaic.tif Out=Nuage3D.ply 64B=true Bin=0"
time -p mm3d Nuage2Ply MEC-Malt/NuageImProf_STD-MALT_Etape_8.xml Attr=Ortho-MEC-Malt/Orthophotomosaic.tif Out=Nuage3D.ply 64B=true Bin=0 >> output.txt
echo "-------------------------------------------------------------------------------------------------------------------------------------"

echo "-------------------------------------------------------------------------------------------------------------------------------------"
echo "Visualize 3D point cloud"
echo "meshlab Nuage3D.ply"
meshlab Nuage3D.ply
echo "-------------------------------------------------------------------------------------------------------------------------------------"

